@@ -20,9 +20,11 @@ class Px(Client, table=True):
     profession_id: Optional[uuid.UUID] = Field(default=None, foreign_key="profession.profession_id")
     education_id: Optional[uuid.UUID] = Field(default=None, foreign_key="education.education_id")
     user_id: Optional[uuid.UUID] = Field(default=None, foreign_key="user.user_id")
+    nationality_id: Optional[uuid.UUID] = Field(default=None, foreign_key="nationality.nationality_id")
 
 Px.marriage_status = Relationship()
 Px.profession = Relationship()
 Px.education = Relationship()
 Px.user = Relationship()
+Px.nationality = Relationship()
 Px.medical_labs = Relationship(back_populates="pxs", link_model="ClientLab")
\ No newline at end of file
